@@ -6,9 +6,11 @@ from doctest import ELLIPSIS, OutputChecker
 from pathlib import Path
 
 import pytest
+
 from pip._vendor.packaging.utils import canonicalize_name
 
 from pip._internal.models.direct_url import DirectUrl, DirInfo
+
 from tests.lib import (
     PipTestEnvironment,
     TestData,
@@ -22,7 +24,6 @@ from tests.lib import (
     need_svn,
     wheel,
 )
-from tests.lib.direct_url import get_created_direct_url_path
 from tests.lib.venv import VirtualEnvironment
 
 distribute_re = re.compile("^distribute==[0-9.]+\n", re.MULTILINE)
@@ -97,38 +98,33 @@ def test_freeze_with_pip(script: PipTestEnvironment) -> None:
 
 def test_freeze_with_setuptools(script: PipTestEnvironment) -> None:
     """
-    Test that pip shows setuptools only when --all is used
-    or _should_suppress_build_backends() returns false
+    Test that pip shows setuptools only when --all is used on Python < 3.12,
+    otherwise it should be shown in default freeze output.
     """
 
     result = script.pip("freeze", "--all")
     assert "setuptools==" in result.stdout
 
-    (script.site_packages_path / "mock.pth").write_text("import mock\n")
-
-    (script.site_packages_path / "mock.py").write_text(
-        textwrap.dedent(
-            """\
-                import pip._internal.commands.freeze as freeze
-                freeze._should_suppress_build_backends = lambda: False
-            """
-        )
-    )
-
+    # Test the default behavior (without --all)
     result = script.pip("freeze")
-    assert "setuptools==" in result.stdout
 
-    (script.site_packages_path / "mock.py").write_text(
-        textwrap.dedent(
-            """\
-                import pip._internal.commands.freeze as freeze
-                freeze._should_suppress_build_backends = lambda: True
-            """
+    should_suppress = sys.version_info < (3, 12)
+    if should_suppress:
+        # setuptools should be hidden in default freeze output
+        assert "setuptools==" not in result.stdout, (
+            f"setuptools should be suppressed in Python {sys.version_info[:2]} "
+            f"but was found in freeze output: {result.stdout}"
+        )
+    else:
+        # setuptools should be shown in default freeze output
+        assert "setuptools==" in result.stdout, (
+            f"setuptools should be shown in Python {sys.version_info[:2]} "
+            f"but was not found in freeze output: {result.stdout}"
         )
-    )
 
-    result = script.pip("freeze")
-    assert "setuptools==" not in result.stdout
+    # --all should always show setuptools regardless of version
+    result_all = script.pip("freeze", "--all")
+    assert "setuptools==" in result_all.stdout
 
 
 def test_exclude_and_normalization(script: PipTestEnvironment, tmpdir: Path) -> None:
@@ -213,7 +209,7 @@ def test_freeze_editable_not_vcs(script: PipTestEnvironment) -> None:
     # Rename the .git directory so the directory is no longer recognized
     # as a VCS directory.
     os.rename(os.path.join(pkg_path, ".git"), os.path.join(pkg_path, ".bak"))
-    script.pip("install", "-e", pkg_path)
+    script.pip("install", "--no-build-isolation", "-e", pkg_path)
     result = script.pip("freeze")
 
     # We need to apply os.path.normcase() to the path since that is what
@@ -235,7 +231,7 @@ def test_freeze_editable_git_with_no_remote(
     Test an editable Git install with no remote url.
     """
     pkg_path = _create_test_package(script.scratch_path)
-    script.pip("install", "-e", pkg_path)
+    script.pip("install", "--no-build-isolation", "-e", pkg_path)
     result = script.pip("freeze")
 
     if not deprecated_python:
@@ -599,7 +595,7 @@ def test_freeze_nested_vcs(
         os.fspath(src_path),
         expect_stderr=True,
     )
-    script.pip("install", "-e", src_path, expect_stderr=True)
+    script.pip("install", "--no-build-isolation", "-e", src_path, expect_stderr=True)
 
     # Check the freeze output recognizes the inner VCS.
     result = script.pip("freeze", expect_stderr=True)
@@ -997,7 +993,7 @@ def test_freeze_direct_url_archive(
     script: PipTestEnvironment, shared_data: TestData
 ) -> None:
     req = "simple @ " + shared_data.packages.joinpath("simple-2.0.tar.gz").as_uri()
-    script.pip("install", req)
+    script.pip("install", "--no-build-isolation", req)
     result = script.pip("freeze")
     assert req in result.stdout
 
@@ -1041,8 +1037,8 @@ def test_freeze_pep610_editable(script: PipTestEnvironment) -> None:
     is correctly frozeon as editable.
     """
     pkg_path = _create_test_package(script.scratch_path, name="testpkg")
-    result = script.pip("install", pkg_path)
-    direct_url_path = get_created_direct_url_path(result, "testpkg")
+    result = script.pip("install", "--no-build-isolation", pkg_path)
+    direct_url_path = result.get_created_direct_url_path("testpkg")
     assert direct_url_path
     # patch direct_url.json to simulate an editable install
     with open(direct_url_path) as f:
