@@ -1,11 +1,15 @@
+from __future__ import annotations
+
 import os
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any
 
-import pytest
 import tomli_w
 
-from pip._internal.build_env import BuildEnvironment
+from pip._internal.build_env import (
+    BuildEnvironment,
+    SubprocessBuildEnvironmentInstaller,
+)
 from pip._internal.req import InstallRequirement
 
 from tests.lib import (
@@ -18,14 +22,14 @@ from tests.lib import (
 
 def make_project(
     tmpdir: Path,
-    requires: Optional[List[str]] = None,
-    backend: Optional[str] = None,
-    backend_path: Optional[List[str]] = None,
+    requires: list[str] | None = None,
+    backend: str | None = None,
+    backend_path: list[str] | None = None,
 ) -> Path:
     requires = requires or []
     project_dir = tmpdir / "project"
     project_dir.mkdir()
-    buildsys: Dict[str, Any] = {"requires": requires}
+    buildsys: dict[str, Any] = {"requires": requires}
     if backend:
         buildsys["build-backend"] = backend
     if backend_path:
@@ -41,9 +45,9 @@ def test_backend(tmpdir: Path, data: TestData) -> None:
     req = InstallRequirement(None, None)
     req.source_dir = os.fspath(project_dir)  # make req believe it has been unpacked
     req.load_pyproject_toml()
-    env = BuildEnvironment()
     finder = make_test_finder(find_links=[data.backends])
-    env.install_requirements(finder, ["dummy_backend"], "normal", kind="Installing")
+    env = BuildEnvironment(SubprocessBuildEnvironmentInstaller(finder))
+    env.install_requirements(["dummy_backend"], "normal", kind="Installing")
     conflicting, missing = env.check_requirements(["dummy_backend"])
     assert not conflicting
     assert not missing
@@ -71,7 +75,7 @@ def test_backend_path(tmpdir: Path, data: TestData) -> None:
     req.source_dir = os.fspath(project_dir)  # make req believe it has been unpacked
     req.load_pyproject_toml()
 
-    env = BuildEnvironment()
+    env = BuildEnvironment(object())  # type: ignore
     assert hasattr(req.pep517_backend, "build_wheel")
     with env:
         assert req.pep517_backend is not None
@@ -89,9 +93,9 @@ def test_backend_path_and_dep(tmpdir: Path, data: TestData) -> None:
     req = InstallRequirement(None, None)
     req.source_dir = os.fspath(project_dir)  # make req believe it has been unpacked
     req.load_pyproject_toml()
-    env = BuildEnvironment()
     finder = make_test_finder(find_links=[data.backends])
-    env.install_requirements(finder, ["dummy_backend"], "normal", kind="Installing")
+    env = BuildEnvironment(SubprocessBuildEnvironmentInstaller(finder))
+    env.install_requirements(["dummy_backend"], "normal", kind="Installing")
 
     assert hasattr(req.pep517_backend, "build_wheel")
     with env:
@@ -124,25 +128,6 @@ def test_pep517_install_with_reqs(
     result.assert_installed("project", editable=False)
 
 
-def test_no_use_pep517_without_setup_py(
-    script: PipTestEnvironment, tmpdir: Path, data: TestData
-) -> None:
-    """Using --no-use-pep517 requires setup.py"""
-    project_dir = make_project(
-        tmpdir, requires=["test_backend"], backend="test_backend"
-    )
-    result = script.pip(
-        "install",
-        "--no-index",
-        "--no-use-pep517",
-        "-f",
-        data.backends,
-        project_dir,
-        expect_error=True,
-    )
-    assert "project does not have a setup.py" in result.stderr
-
-
 def test_conflicting_pep517_backend_requirements(
     script: PipTestEnvironment, tmpdir: Path, data: TestData
 ) -> None:
@@ -301,13 +286,13 @@ def test_pep517_install_with_no_cache_dir(
 
 def make_pyproject_with_setup(
     tmpdir: Path, build_system: bool = True, set_backend: bool = True
-) -> Tuple[Path, str]:
+) -> tuple[Path, str]:
     project_dir = tmpdir / "project"
     project_dir.mkdir()
     setup_script = "from setuptools import setup\n"
     expect_script_dir_on_path = True
     if build_system:
-        buildsys: Dict[str, Any] = {
+        buildsys: dict[str, Any] = {
             "requires": ["setuptools", "wheel"],
         }
         if set_backend:
@@ -385,45 +370,3 @@ def test_explicit_setuptools_backend(
         project_dir,
     )
     result.assert_installed(name, editable=False)
-
-
-@pytest.mark.network
-def test_pep517_and_build_options(
-    script: PipTestEnvironment, tmpdir: Path, data: TestData, common_wheels: Path
-) -> None:
-    """Backend generated requirements are installed in the build env"""
-    project_dir, name = make_pyproject_with_setup(tmpdir)
-    result = script.pip(
-        "wheel",
-        "--wheel-dir",
-        tmpdir,
-        "--build-option",
-        "foo",
-        "-f",
-        common_wheels,
-        project_dir,
-        allow_stderr_warning=True,
-    )
-    assert "Ignoring --build-option when building" in result.stderr
-    assert "using PEP 517" in result.stderr
-
-
-@pytest.mark.network
-def test_pep517_and_global_options(
-    script: PipTestEnvironment, tmpdir: Path, data: TestData, common_wheels: Path
-) -> None:
-    """Backend generated requirements are installed in the build env"""
-    project_dir, name = make_pyproject_with_setup(tmpdir)
-    result = script.pip(
-        "wheel",
-        "--wheel-dir",
-        tmpdir,
-        "--global-option",
-        "foo",
-        "-f",
-        common_wheels,
-        project_dir,
-        allow_stderr_warning=True,
-    )
-    assert "Ignoring --global-option when building" in result.stderr
-    assert "using PEP 517" in result.stderr
