@@ -113,7 +113,12 @@ class TestSiteConfigDirs:
     def test_site_config_dirs_osx_homebrew(
         self, monkeypatch: pytest.MonkeyPatch
     ) -> None:
-        monkeypatch.setattr(sys, "prefix", "/opt/homebrew/")
+        python_version = f"{sys.version_info[0]}.{sys.version_info[1]}"
+        monkeypatch.setattr(
+            sys,
+            "prefix",
+            f"/opt/homebrew/opt/python@{python_version}/Frameworks/Python.framework/Versions/{python_version}",
+        )
 
         assert appdirs.site_config_dirs("pip") == [
             "/opt/homebrew/share/pip",
