@@ -1,16 +1,18 @@
+from __future__ import annotations
+
 import os
 import pathlib
 import shutil
 import subprocess
 import sys
+from collections.abc import Iterable
 from glob import glob
-from typing import Iterable, Union
 
 VIRTUAL_ENV = os.environ["VIRTUAL_ENV"]
 TOX_PIP_DIR = os.path.join(VIRTUAL_ENV, "pip")
 
 
-def pip(args: Iterable[Union[str, pathlib.Path]]) -> None:
+def pip(args: Iterable[str | pathlib.Path]) -> None:
     # First things first, get a recent (stable) version of pip.
     if not os.path.exists(TOX_PIP_DIR):
         subprocess.check_call(
